==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicDesktopPaneUI__24OpenAction.h <==
// public class javax.swing.plaf.basic.BasicDesktopPaneUI$OpenAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class bc1b004e2cb5e52b javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$_init$c5ed387795e3a8dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$isEnabled$93ecf19b136b3f6c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method_info$isEnabled$93ecf19b136b3f6c;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
	jboolean	(*isEnabled$93ecf19b136b3f6c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object {
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicDesktopPaneUI__24OpenAction.h <==
// public class javax.swing.plaf.basic.BasicDesktopPaneUI$OpenAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class bc1b004e2cb5e52b javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_
#define _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$_init$c5ed387795e3a8dc(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method$isEnabled$93ecf19b136b3f6c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method_info$actionPerformed$9046a9754e643ffd;
extern _jc_method _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$method_info$isEnabled$93ecf19b136b3f6c;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isEnabled$93ecf19b136b3f6c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vmethods	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs {
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_refs	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$sub_nonrefs	javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$object {
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$vtype _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicDesktopPaneUI__24OpenAction_H_ */
